@@ -1,16 +1,15 @@
 from abc import ABC, abstractmethod
-from .get_arguments import get_argument
-
+from alidaargparser import get_asset_property
 
 class FileIO(ABC):
 
     def __new__(cls, *args, **kw):
-        if 'storage_type' in kw:
-            storage_type = kw['storage_type'].lower()
-        elif len(args) > 0:
-            storage_type = args[0]
-        elif get_argument("webHdfsUrl") is not None:
-            storage_type = "hdfs"
+
+        if 'name' in kw:
+            # Get storage type from properties
+            storage_type = get_asset_property(asset_name=kw['name'], property="storage_type")
+        elif len(args)>0:
+            storage_type = get_asset_property(asset_name=args[0], property="storage_type")
         else:
             storage_type = "filesystem"
 
@@ -22,9 +21,9 @@ class FileIO(ABC):
         instance = super(FileIO, subclass).__new__(subclass)
         return instance
     
-    def __init__(self, storage_type = None):
+    def __init__(self, name = None):
         super().__init__()
-
+      
     @abstractmethod
     def upload(self, local_path, remote_path):
         pass
@@ -36,3 +35,6 @@ class FileIO(ABC):
     @abstractmethod
     def get_modification_time(self, path):
         pass
+
+    def get_remote_path(self):
+        return get_asset_property(asset_name=self.name)
\ No newline at end of file
